@@ -129,6 +129,9 @@ def _find_dirs_meeting_func(src, check_func):
     tqdm_kwargs = {
         "desc": "Walking through directories and applying `check_func`",
         "leave": True,
+        "mininterval": 10,
+        "unit": "it",
+        "unit_scale": True,
     }
     for dirpath, _, filenames in tqdm.tqdm(os.walk(src), **tqdm_kwargs):
         LOGGER.debug("Entering %s", dirpath)
